@@ -17,7 +17,6 @@ class BoundingBox:
         self.top = top
         self.right = right
         self.bottom = bottom
-
         self.height = self.top - self.bottom
         self.width = self.right - self.left
 
@@ -105,6 +104,15 @@ class BoundingBox:
         ver_intersection = self.bottom <= other.top and other.bottom <= self.top
         return hor_intersection and ver_intersection
 
+    def contains_point(self, point: Point) -> bool:
+        """Check if the bounding box contains the point."""
+        return (
+            self.left <= point.x
+            and self.right >= point.x
+            and self.bottom <= point.y
+            and self.top >= point.y
+        )
+
     def __le__(self, other):
         """Check if the bounding box is weakly inside the other bounding box."""
         return (
@@ -169,3 +177,19 @@ class BoundingBox:
                 )
             )
         return bounding_boxes
+
+    def draw_on_image(
+        self, image_drawer, color, image_width, image_height, fill=False, width=1
+    ):
+        """Draw the bounding box on an image."""
+        left = self.left * image_width
+        right = self.right * image_width
+        top = image_height - self.top * image_height
+        bottom = image_height - self.bottom * image_height
+        if fill:
+            image_drawer.rectangle([left, top, right, bottom], fill=color)
+
+        else:
+            image_drawer.rectangle(
+                [left, top, right, bottom], outline=color, width=width
+            )
