@@ -1,11 +1,7 @@
-import logging
-
 import attr
-
 from ..bounding_box import BoundingBox
 from ..constants import PARAGRAPH_HORIZONTAL_SCALE, PARAGRAPH_VERTICAL_SCALE
 from ..graph import Graph, Node
-from ..segment import Segment
 from ..text_block import Line, Paragraph
 
 
@@ -26,8 +22,8 @@ class ParagraphMerger:
         self.graph: Graph = None
 
     def is_directed_edge(self, first_node: Node, second_node: Node):
-        first_bb = self.paragraphs[first_node.index].bounding_box
-        second_bb = self.paragraphs[second_node.index].bounding_box
+        first_bb = self.paragraphs[first_node.data].bounding_box
+        second_bb = self.paragraphs[second_node.data].bounding_box
         return first_bb.intersect(second_bb)
 
     def build_graph(self):
@@ -53,8 +49,8 @@ class ParagraphMerger:
         lines_indexes = []
         bounding_boxes = []
         for node in cc:
-            lines_indexes.extend(self.paragraphs[node.index].lines_indexes)
-            bounding_boxes.append(self.paragraphs[node.index].bounding_box)
+            lines_indexes.extend(self.paragraphs[node.data].lines_indexes)
+            bounding_boxes.append(self.paragraphs[node.data].bounding_box)
         bounding_box = BoundingBox.compose_bounding_boxes(bounding_boxes)
         return ParagraphIndexed(lines_indexes, bounding_box)
 
@@ -76,10 +72,10 @@ class ParagraphExtractor:
                     nodes[j].add_neighbor(nodes[i])
 
     def are_adjacent(self, first_node: Node, second_node: Node) -> bool:
-        first_scaled_bb = self.lines[first_node.index].bounding_box.scale(
+        first_scaled_bb = self.lines[first_node.data].bounding_box.scale(
             PARAGRAPH_HORIZONTAL_SCALE, PARAGRAPH_VERTICAL_SCALE
         )
-        second_scaled_bb = self.lines[second_node.index].bounding_box.scale(
+        second_scaled_bb = self.lines[second_node.data].bounding_box.scale(
             PARAGRAPH_HORIZONTAL_SCALE, PARAGRAPH_VERTICAL_SCALE
         )
         return first_scaled_bb.intersect(second_scaled_bb)
@@ -89,7 +85,7 @@ class ParagraphExtractor:
     ) -> list[ParagraphIndexed]:
         paragraphs = []
         for cc in ccs:
-            lines_indexes = [node.index for node in cc]
+            lines_indexes = [node.data for node in cc]
             bounding_boxes = [self.lines[i].bounding_box for i in lines_indexes]
             bounding_box = BoundingBox.compose_bounding_boxes(bounding_boxes)
             paragraphs.append(ParagraphIndexed(lines_indexes, bounding_box))
