@@ -60,13 +60,19 @@ class TextractParser:
             line.add_child(child_block_object)
         return line
 
+    def is_printed(self, block_dict: dict) -> bool:
+        """
+        Check if a block dict is printed
+        """
+        return block_dict["TextType"] == "PRINTED"
+
     def get_word(self, block_dict: dict) -> Word:
         """
         Get a word object from a block dict
         """
         bb = self.get_bounding_box(block_dict)
         text = block_dict["Text"]
-        block = Word(bounding_box=bb, text=text)
+        block = Word(bounding_box=bb, text=text, printed=self.is_printed(block_dict))
         return block
 
     def split_blocks_by_type(self):
